function [Reported_D,Notinfected_D,Unreported_D,Infected_D,Recovered_D,Dead_D,Infected_T,Y_D,Y_T,M_T,A_daily,Pt,number_tests_D,Rt,RtC,rU_D] ...
    =corona_func(policy,model,experiment)

global hrs disimm rel_rho R0 lambda rel_lambda
global Pop ini_inf T_years  T  d_vaccine  rel_prod_Q
global sigma gamma tau psi d_conv V_false_neg S_false_neg
global rU_start
%Store for experiment below
xiU_exp     = policy.xiU;
rU_exp      = policy.rU_exp;
tauV_exp    = policy.tauV;
tauS_exp    = policy.tauS;
d_start_exp = policy.d_start_exp;
d_start_reopen  = policy.d_start_reopen;
d_start_testing  = policy.d_start_testing;

omegaD   = model.omegaD  ;
lambdaQ  = model.lambdaQ ;
rhoS     = model.rhoS ;
rhoA     = model.rhoA ;


% vaccine rate
nu       = 1-(1-.015)^(1/hrs);

% %__________________________________________________________________________
% % Derived parameters

%__________________________________________________________________________
% States
% 1.  S_u_NQ    -> susceptible unknown NQ
% 2.  S_u_Q     -> susceptible unknown Q

% 3.  tA_u_NQ   -> temporary asymptomatic unknown NQ
% 4.  tA_u_Q    -> temporary asymptomatic unknown Q
% 5.  tA_+_Q    -> temporary asymptomatic known positive Q

% 6.  I_+_Q     -> symptomatic Q

% 7.  pA_u_NQ   -> permanent asymptomatic unknown NQ
% 8.  pA_u_Q    -> permanent asymptomatic unknown Q
% 9.  pA_+_Q    -> temporary asymptomatic positive Q

% 10. R_u_NQ    -> recovered unknown NQ
% 11. R_u_Q     -> recovered unknown Q
% 12. R_-_NQ    -> recovered known negative Q

% 13. D         -> Death
%__________________________________________________________________________
% Initial conditions

M0_vec          = zeros(13,1);
M0_vec(3)       = (ini_inf/Pop)*psi;
M0_vec(7)       = (ini_inf/Pop)*(1-psi);

% Remaining are S_NQ^{u}
M0_vec(1)      = 1-sum(M0_vec);

iQ             = [2,4,5,6,8,9,11]';
iNQ            = [1,3,7,10,12]';

iSNQ           = [1]';
iRNQ           = [10,12]';

iSQ            = [2]';
iRQ            = [11]';

iANQ           = [3,7]';
iAQ            = [4,5,8,9];

iIpQ           = [6]';  

M_T            = zeros(13,T);
M_T(:,1)       = M0_vec;

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
betatilde_t     = zeros(T,1);
Upsilon_t       = zeros(T,1);
Pt_array        = zeros(13,13,T);

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

rU=0;

for tt = (1:T)
    %______________________________________________________________________
    % 0. Initial state
    Mt              = M_T(:,tt);
    %______________________________________________________________________
    % 1. Compute infection rate - alphat
    Mt_Q            = sum(Mt(iQ));
    Mt_NQ           = sum(Mt(iNQ));
    
    Mt_SNQ          = sum(Mt(iSNQ));
    Mt_RNQ          = sum(Mt(iRNQ));
    
    Mt_SQ           = sum(Mt(iSQ));
    Mt_RQ           = sum(Mt(iRQ));
    
    Mt_ANQ          = sum(Mt(iANQ));
    Mt_AQ           = sum(Mt(iAQ));
    
    Mt_IpQ          = sum(Mt(iIpQ));
    
    Mt_Total        = lambda*Mt_NQ + lambdaQ*Mt_Q;

    Mt_I            = lambda*(Mt_ANQ) + lambdaQ*(Mt_AQ + Mt_IpQ);
    Mt_N            = lambda*(Mt_SNQ + Mt_RNQ) + lambdaQ*(Mt_SQ + Mt_RQ);

    pit_I           = Mt_I/Mt_Total;
    pit_IA          = (lambda*Mt_ANQ + lambdaQ*Mt_AQ)/Mt_I;
    pit_IIp         = lambdaQ*Mt_IpQ/Mt_I;
    
    alphat          = pit_I*(pit_IIp*rhoS + pit_IA*rhoA);
    %______________________________________________________________________
    betatilde_t(tt) = (lambda*Mt_SNQ + lambdaQ*Mt_SQ)/Mt_Total;
    Upsilon_t(tt)   = (lambda*Mt_SNQ)/ (lambda*Mt_SNQ + lambdaQ*Mt_SQ);
    
    %______________________________________________________________________
    
    if tt<=d_start_exp %Quarantine experiment
        xiU  = 0;
        tauV = 0;
        tauS = 0;
    else
        tauV = 0;
        tauS = 0;   
        xiU  = xiU_exp;    
    end
    
    if (tt>hrs)
        Daily_deaths_per_million    = (M_T(13,tt)-M_T(13,tt-hrs))*Pop / (Pop/1e6);
    end
    
    if (tt == d_start_reopen-1) 
        Daily_deaths_0              = Daily_deaths_per_million;
    elseif  (tt > d_start_reopen) 
       rU                           = rU_exp + rU_start*max(0, (Daily_deaths_0-Daily_deaths_per_million)/Daily_deaths_0 );       
    end
    
    %~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~                       
    if (tt>=d_start_testing)             
        tauV = tauV_exp;
        tauS = tauS_exp;         
    end             
    %~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~     
    
    tauV_vec(tt)    = tauV;
    tauS_vec(tt)    = tauS;
    xiU_vec(tt)     = xiU;
    % record components of rU
    rU_vec(tt)      = rU;
        
    if  (tt > d_start_reopen)
        rU_endogenous_vec(tt) = rU - rU_exp;
        rU_exp_vec(tt)        = rU_exp ;
    else
        rU_endogenous_vec(tt) = 0;
        rU_exp_vec(tt)        = 0;
    end
    %______________________________________________________________________
    
    % 2. Put together transition matrix
    post_vac        = tt >= d_vaccine ;
    Pt              = zeros(13,13);

    Pt(1,2)         = xiU;
    Pt(1,3)         = lambda*alphat*psi;
    Pt(1,7)         = lambda*alphat*(1-psi);
    Pt(1,12)        = post_vac*nu;
    
    Pt(2,1)         = rU;
    Pt(2,4)         = lambdaQ*alphat*psi;
    Pt(2,8)         = lambdaQ*alphat*(1-psi);        
    Pt(2,12)        = post_vac*nu ;
    
    Pt(3,4)         = xiU;
    Pt(3,5)         = (1- V_false_neg)*tauV;       
    Pt(3,6)         = 1/sigma;
    Pt(3,9)         = post_vac*nu;
    
    Pt(4,3)         = rU;
    Pt(4,5)         = (1- V_false_neg)*tauV;         
    Pt(4,6)         = 1/sigma;
    Pt(4,9)         = post_vac*nu;
    
    Pt(5,6)         = 1/sigma;

    Pt(6,12)        = 1/gamma;          % I+ recover to known negative
%     Pt(6,11)        = 1/gamma;        % I+ recover to unknown negative
    Pt(6,13)        = omegaD;
    
    Pt(7,8)         = xiU;
    Pt(7,9)         = (1 - V_false_neg)*tauV + post_vac*nu;
    Pt(7,10)        = 1/(sigma+gamma);
    
    Pt(8,7)         = rU;
    Pt(8,9)         = (1 - V_false_neg)*tauV + post_vac*nu; 
    Pt(8,11)        = 1/(sigma+gamma);
    
    Pt(9,12)        = 1/(sigma+gamma);      %PA recover to known negative 
%    Pt(9,11)        = 1/(sigma+gamma);     %PA recover to unknown negative 
	
    Pt(10,11)       = xiU;
    Pt(10,12)       = (1 - S_false_neg)*tauS + post_vac*nu;
    Pt(10,3)        = disimm*lambda*alphat*psi     ; % reinfection
    Pt(10,7)        = disimm*lambda*alphat*(1-psi) ; % reinfection
    
    
    Pt(11,10)       = rU;      
    Pt(11,12)       = (1 - S_false_neg)*tauS + post_vac*nu;
    Pt(11,4)        = disimm*lambdaQ*alphat*psi     ; % reinfection
    Pt(11,8)        = disimm*lambdaQ*alphat*(1-psi) ; % reinfection
    
 
    Pt(12,3)        = disimm*lambda*alphat*psi     ; % reinfection
    Pt(12,7)        = disimm*lambda*alphat*(1-psi) ; % reinfection
    
   
    Pt              = Pt + diag(1-sum(Pt,2)); 
    
    Pt_array(:,:,tt) = Pt;
    
    %______________________________________________________________________
    % Checks
    if min(min(Pt))<0 
        keyboard
    end
    assert(min(min(Pt))>=0);
    assert(max(max(Pt))<=1);
    assert(all(abs(sum(Pt,2)-1)<1e-8));  
    %______________________________________________________________________
    % 3. Iterate forward the distribution
    if (tt < T)
        M_T(:,tt+1)     = Pt'*Mt;
    end
    
   
end


%__________________________________________________________________________
% Generate measures of activity
Y_T         = sum(M_T([1,3,7,10,12]',:)) + rel_prod_Q*sum(M_T([2,4,5,8,9,11]',:));

% Reported cases
Reported_T  = zeros(T,1); 	
for tt = (2:T)
    % reported cases include 1.asym who tested positive 2. unknown asym
    % develop symptoms
    Reported_T(tt)   = Reported_T(tt-1) ...
        + Pop*tauV_vec(tt)*(M_T(3,tt) + M_T(4,tt)+M_T(7,tt) + M_T(8,tt)) ...
        + Pop*(1/sigma)*(M_T(3,tt) + M_T(4,tt));
end

% number of tests
number_tests_T  = zeros(T,1); 	
for tt = (2:T)
    number_tests_T(tt)   = number_tests_T(tt-1) ...
        + Pop*(tauV_vec(tt)+tauS_vec(tt))*sum(M_T([1,2,3,4,7,8,10,11]',tt)) ; %Test all unknown, accumulate
end


Rvect           = zeros(13,T);
Rvect(:,T)      = zeros(13,1);
Rt              = zeros(T,1);
RtC             = zeros(T,1);


rvec            = [0,...
                   0,...
                    rhoA*lambda,...
                    rhoA*lambdaQ,...
                    rhoA*lambdaQ,...
                    rhoS*lambdaQ,...    % I
                    rhoA*lambda,...
                    rhoA*lambdaQ,...
                    rhoA*lambdaQ,...
                    0,...
                    0,...
                    0,...
                    0]';
for tt = T-1:-1:1
   Pmat_t       = Pt_array(:,:,tt);
   Rvect(:,tt)  = betatilde_t(tt)*rvec + Pmat_t*Rvect(:,tt+1);
   Rt(tt)       =        Upsilon_t(tt)*(psi*Rvect(3,tt) + (1-psi)*Rvect(7,tt)) ...
                    +(1-Upsilon_t(tt))*(psi*Rvect(4,tt) + (1-psi)*Rvect(8,tt));

   % Cori method
if strcmp(experiment,'exp1_CoriR')
    
    RvectC          = zeros(13,1);
    for iterC = (1:800)
          RvectC    = betatilde_t(tt)*rvec + Pmat_t*RvectC;
    end
    RtC(tt)     =        Upsilon_t(tt)*(psi*RvectC(3) + (1-psi)*RvectC(7)) ...
                    +(1-Upsilon_t(tt))*(psi*RvectC(4) + (1-psi)*RvectC(8));                
end

end
 

% get indicator for at the end the day indicator
A_daily             = (repmat([1:hrs]',T/hrs,1)==hrs)';

Rt                  = Rt(A_daily);
RtC                 = RtC(A_daily);
number_tests_D      = number_tests_T(A_daily);
Reported_D          = Reported_T(A_daily);
Notinfected_D       = Pop*sum(M_T([1,2]',A_daily))';
Unreported_D        = Pop*sum(M_T([3,4,7,8]',A_daily))';
% infected_D are only Ip people
Infected_D          = Pop*M_T(6,A_daily)';
Recovered_D         = Pop*sum(M_T([10,11,12]',A_daily))';
Dead_D              = Pop*M_T(13,A_daily)';
Infected_T          = Pop*sum(M_T([3:9]',:))';
Y_D                 = Pop*Y_T(A_daily);%Output
Y_T                 = Pop*Y_T;

rU_D                = rU_vec(A_daily);
rU_exp_D            = rU_exp_vec(A_daily);
rU_endo_D           = rU_endogenous_vec(A_daily);
    
eval(['save baseline_' num2str(experiment)])


 