clear all
clc
close all

global hrs disimm rel_rho R0 lambda rel_lambda
global Pop ini_inf T_years  T  d_vaccine  rel_prod_Q
global sigma gamma tau psi D_lower d_conv V_false_neg S_false_neg
global rU_start

V_false_neg_grid        = [0 0.5];
for V_false_neg = V_false_neg_grid
%__________________________________________________________________________

rU_start        		= 0.00275;    
reopen_date     		= datetime(2020,6,1);
days_Mar20_to_reopen    = days(reopen_date-datetime(2020,3,20));

testing_date     		= datetime(2020,6,1);
days_Mar20_to_testing   = days(testing_date-datetime(2020,3,20));

vaccine_date            = datetime(2021,3,20);
days_Mar20_to_vaccine   = days(vaccine_date-datetime(2020,3,20));

%__________________________________________________________________________
%Policy parameters - Fixed
xiU_c                   = 0.0026;       % constant quarantine rate for unknown  (hourly)
rU_exp                  = 0 ;    		% additional reopening rate

% S tests have no false negatives for baseline
S_false_neg             = 0; 
%__________________________________________________________________________
% Quarantine technology
rel_lambda              = 0.16 ;        % lambdaQ/lambda
%__________________________________________________________________________
% Time step
hrs                     = 14;           % Periods per day       
%__________________________________________________________________________
% Parameters
rel_prod_Q              = 0.9;              % Relative productivity of quarantined (A_rel in paper)
disimm                  = 0;                % Dis-Immunity  (0 = complete immunity, 1 = no immunity) 
rel_rho                 = 1;                % rhoA/rhoS    Relative infectiousness rate 

psi                     = 0.6;              % Fraction who develop symptoms (TA)

sigma                   = hrs*6;            % for transition matrix
gamma                   = hrs*8;            % for transition matrix

R0                      = 2.6;              % Basic reproduction number
lambda                  = 1;                % Meeting rate (=1 is a normalization) 					
Pop                     = 340000000;        % Population
T_years                 = 5;                
T                       = T_years*365*hrs;  
ini_inf                 = 340000;           % 0.1% infected
%__________________________________________________________________________
% Bisection stuff
% d_conv is the date when we define 'long term' for target deaths
d_conv       			= 1000;

death_inflator          = 1.33;  % Jones Villaverde
deaths_March20          = 277*death_inflator;

%% Solve for omegaD that delivers the desired infection_fatality rate
infection_fatality_target = .01; %Target fatality rate of infection -- fraction of people who die from infection 
% infection_fatality_target = IFR;

Pt              = zeros(13,13);
Pt(3,6)         = 1/sigma;
Pt(4,6)         = 1/sigma;
Pt(5,6)         = 1/sigma;
Pt(6,12)        = 1/gamma;
Pt(7,10)        = 1/(sigma+gamma);
Pt(8,11)        = 1/(sigma+gamma);
Pt(9,12)        = 1/(sigma+gamma);
M0              = zeros(13,1);
M0(3)           = psi;
M0(7)           = (1-psi);

maxiter_piD     = 1000;
tol_piD         = 1e-9;
omegaD_min      = 0.0;
omegaD_max      = 1-1/gamma-1e-8;

for iter_omegaD     = (1:maxiter_piD)
    omegaD          = 0.5*(omegaD_min + omegaD_max);
    Pt(6,13)        = omegaD;
    Pdeath          = Pt + diag(1-sum(Pt,2)); 
    ergodic_dist    = (Pdeath')^10000*M0;    

    % All infections
    death_rate_true =  ergodic_dist(13);

    dist_piD        = abs(death_rate_true-infection_fatality_target);
    if dist_piD<tol_piD
        break;
    end
    if (death_rate_true < infection_fatality_target)
        omegaD_min  = omegaD;
    else
        omegaD_max  = omegaD;
    end
    
end

display(['Infection Fatality Rate: ' num2str(death_rate_true) ' : diff_piD : ' num2str(dist_piD) ])
display(['Infection Fatality Rate Percent: ' num2str(100*death_rate_true) ])

fprintf('omegaD = %1.4e\n',omegaD);

%% Set up parameters

model.omegaD      = omegaD;
model.lambdaQ     = rel_lambda*lambda;
model.rhoS        = R0/(psi*sigma*lambda*(rel_rho+(1/sigma)/((1/gamma)+model.omegaD)) + (1-psi)*(sigma+gamma)*lambda*rel_rho) ;
model.rhoA        = rel_rho* model.rhoS; 


    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %1. Compute Tstar in Quarantine Only Environment
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %Run it with no policy to get tstar!!
    Tstar_guess             = 365;                          % Big guess for the first iteration
    
    d_vaccine               = days_Mar20_to_vaccine*hrs+ Tstar_guess*hrs;     % vaccine available date     
    
    % no test, no release, only xi_U nonzero

    policy1.tauV			= 0;
    policy1.tauS			= 0;
    policy1.xiU				= xiU_c;
    policy1.rU_exp          = rU_exp;                  
    policy1.d_start_exp 	=  Tstar_guess*hrs;       
    policy1.d_start_reopen  =  Tstar_guess*hrs; 
    policy1.d_start_testing =  Tstar_guess*hrs;     

    experiment              = 'exp1';

    [Reported_D_exp1,Notinfected_D_exp1,Unreported_D_exp1,Infected_D_exp1,Recovered_D_exp1,Dead_D_exp1,Infected_T_exp1,Y_D_exp1,Y_T_exp1,M_T_exp1,A_daily,Pt_exp1,number_tests_D_exp1,Rt_D_exp1]  =corona_func(policy1,model,experiment);
    
    Tstar               = find(Dead_D_exp1>=deaths_March20,1,'first'); 	
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %2. Run full simulation, with policy starting on Tstar
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Rerun with correct Tstar 
    d_vaccine           = days_Mar20_to_vaccine*hrs+ Tstar*hrs;    
    % no test, no release, only xi_U nonzero
    policy1.tauV		= 0;
    policy1.tauS		= 0;
    policy1.xiU			= xiU_c;
    policy1.rU_exp      = rU_exp;
    policy1.d_start_exp =  Tstar*hrs ; 
    policy1.d_start_reopen  =  Tstar*hrs + days_Mar20_to_reopen*hrs;    
    policy1.d_start_testing =  Tstar*hrs + days_Mar20_to_testing*hrs;     
    
    experiment          = 'exp1';
    clc;
    [Reported_D_exp1,Notinfected_D_exp1,Unreported_D_exp1,Infected_D_exp1,Recovered_D_exp1,Dead_D_exp1,Infected_T_exp1,Y_D_exp1,Y_T_exp1,M_T_exp1,A_daily,Pt_exp1,number_tests_D_exp1,Rt_D_exp1]  =corona_func(policy1,model,experiment);
    Tstar_check         = find(Dead_D_exp1>=deaths_March20,1,'first'); 			
    assert(Tstar==Tstar_check)

%% Non-Constant Deaths: fix xiU, zero rU; Computation part
% 1 week to 4 weeks with a step of 1 day
weeks_grid              = [1:1/7:4] ;
deaths_nobench_grid2    = zeros(1,length(weeks_grid));

days_for_output  = days(vaccine_date - reopen_date);  % reopen date to vaccine date
sum_Y1        = sum(Y_D_exp1((policy1.d_start_reopen/hrs):1:(policy1.d_start_reopen/hrs+days_for_output))-Y_T_exp1(1)) ;  % used Y_T(1) instead of Y_D(1) since Y_T(1) is the *very* initial output
denom         = -sum_Y1 ;

output_nobench_grid2 = zeros(1,length(weeks_grid));

for xx = 1:length(weeks_grid)
    weeks  = weeks_grid(xx) ; 
    tau    = 1/(7*hrs*0.999*weeks);    % constant hourly testing rate
    
    %exp2
    policy2.tauV        = tau;
    policy2.tauS        = 0;
    policy2.xiU         = xiU_c;
    policy2.rU_exp      = rU_exp;      
    policy2.d_start_exp = policy1.d_start_exp ;
    policy2.d_start_reopen = policy1.d_start_reopen ;
    policy2.d_start_testing = policy1.d_start_testing;     
    
    experiment        	= 'exp2';
    
    [exp2.Reported_D,exp2.Notinfected_D,exp2.Unreported_D,exp2.Infected_D,exp2.Recovered_D,exp2.Dead_D,exp2.Infected_T,exp2.Y_D,exp2.Y_T,exp2.M_T,exp2.A_daily,exp2.Pt,exp2.number_tests_D,exp2.Rt_D]  =corona_func(policy2,model,experiment);

    numerator2                  = sum(exp2.Y_T(1) - exp2.Y_D(policy2.d_start_reopen/hrs:1:(policy2.d_start_reopen/hrs+days_for_output)) );
    output_nobench_grid2(xx)    = numerator2/denom;    

    deaths_nobench_grid2(xx)   = exp2.Dead_D(d_conv);

    eval(['all_exp2.nobench.weeks_position' num2str(xx) '= exp2 ;' ])
     
end
deaths_onlyQ  = Dead_D_exp1(d_conv) ;

if V_false_neg == 0
    deaths_positive_xiU_grid   = deaths_nobench_grid2;    
    output_positive_xiU_grid   = output_nobench_grid2;
   
    save('positive_xiU_varying_Vtests.mat','deaths_positive_xiU_grid','weeks_grid','deaths_onlyQ','output_positive_xiU_grid')
elseif V_false_neg == 0.5
    deaths_positive_xiU_falneg_grid   = deaths_nobench_grid2;
    output_positive_xiU_falneg_grid   = output_nobench_grid2;
    
    save('positive_xiU_varying_Vtests_falseneg.mat','deaths_positive_xiU_falneg_grid','output_positive_xiU_falneg_grid')
end

end

%% Plot Figure 11
clear; clc;
default_figures

load positive_xiU_varying_Vtests;

T_days      = 7*weeks_grid;
D_save      = deaths_onlyQ - deaths_positive_xiU_grid;

load positive_xiU_varying_Vtests_falseneg;

D_save_fn   = deaths_onlyQ - deaths_positive_xiU_falneg_grid;

T_per_month = 28./T_days;
i           = (T_days>=7);

CostPerWeeklyTest   = 10;
CostPerMonthlyTest  = 40;


% convert 'output loss ratio' to 'output loss saved' here
output_plot          =    1- output_positive_xiU_grid;
output_falneg_plot   =    1- output_positive_xiU_falneg_grid;

close all;
F1 = figure(1);

set(F1,'Pos',[-2330 78 1303 511]);  

set(0,'defaultlinelinewidth',2);

subplot(1,2,1);
plot(CostPerMonthlyTest*T_per_month(i),  D_save(i)/1000,'bo-');grid on;hold on;
plot(CostPerWeeklyTest*T_per_month(i),   D_save(i)/1000,'s-','color',rgb('Green'));grid on;hold on;
plot(CostPerWeeklyTest*T_per_month(i),   D_save_fn(i)/1000,'d-','color',rgb('Red'));grid on;hold on;
plot(CostPerMonthlyTest*T_per_month(end),D_save(end)/1000,'bo','markersize',18);grid on;hold on;
plot(CostPerWeeklyTest*T_per_month(1),   D_save(1)/1000,'bs','color',rgb('Green'),'markersize',18);grid on;hold on;
plot(CostPerWeeklyTest*T_per_month(end), D_save(end)/1000,'o','color',rgb('Green'),'markersize',18);grid on;hold on;
plot(CostPerMonthlyTest*T_per_month(1),  D_save(1)/1000,'s','color',rgb('Blue'),'markersize',18);grid on;hold on;
plot(CostPerWeeklyTest*T_per_month(1),   D_save_fn(1)/1000,'s','color',rgb('Red'),'markersize',18);grid on;hold on;
plot(CostPerWeeklyTest*T_per_month(end), D_save_fn(end)/1000,'o','color',rgb('Red'),'markersize',18);grid on;hold on;
t1 = text(98,200,'Square = Weekly','interpreter','latex','fontsize',14);
set(t1,'Pos',[89.92660550458723,234.6278317152104,0])
t2 = text(65,150,'Circle $\:\:\:$= Monthly','interpreter','latex','fontsize',14);
set(t2,'Pos',[66.68195718654437,175.5663430420712,0])
l = legend('PCR test - \$40','At home test - \$10','At home test (50\% false negative) - \$10');
set(l,'interpreter','latex','location','SouthEast','fontsize',14);
title('A. Health outcomes - Lives saved','interpreter','latex');
xlabel('Cost per person per month (\$)','interpreter','latex');ylabel('Lives saved (thousands)','interpreter','latex');
set(gca,'ticklabelinterpreter','latex');
set(gca,'fontsize',16);
ytickformat('%4.0f');
xlim([0,165]);
set(gca,'xtick',[0,40,80,120,160]);

subplot(1,2,2);
plot(CostPerMonthlyTest*T_per_month(i),  output_plot(i)*100,'bo-');grid on;hold on;
plot(CostPerWeeklyTest*T_per_month(i),   output_plot(i)*100,'s-','color',rgb('Green'));grid on;hold on;
plot(CostPerWeeklyTest*T_per_month(i),   output_falneg_plot(i)*100,'d-','color',rgb('Red'));grid on;hold on;
plot(CostPerMonthlyTest*T_per_month(end),output_plot(end)*100,'bo','markersize',18);grid on;hold on;
plot(CostPerWeeklyTest*T_per_month(1),   output_plot(1)*100,'bs','color',rgb('Green'),'markersize',18);grid on;hold on;
plot(CostPerWeeklyTest*T_per_month(end), output_plot(end)*100,'o','color',rgb('Green'),'markersize',18);grid on;hold on;
plot(CostPerMonthlyTest*T_per_month(1),  output_plot(1)*100,'s','color',rgb('Blue'),'markersize',18);grid on;hold on;
plot(CostPerWeeklyTest*T_per_month(1),   output_falneg_plot(1)*100,'s','color',rgb('Red'),'markersize',18);grid on;hold on;
plot(CostPerWeeklyTest*T_per_month(end), output_falneg_plot(end)*100,'o','color',rgb('Red'),'markersize',18);grid on;hold on;
t3 = text(98,20,'Square = Weekly','interpreter','latex','fontsize',14);
set(t3,'Pos',[93.9633027522936,20.107874865156415,0])
t4 = text(65,15,'Circle $\:\:\:$= Monthly','interpreter','latex','fontsize',14);
set(t4,'Pos',[73.578,15.6742,0])
l = legend('PCR test - \$40','At home test - \$10','At home test (50\% false negative) - \$10');
set(l,'interpreter','latex','location','SouthEast','fontsize',14);
xlabel('Cost per person per month (\$)','interpreter','latex');
ylabel('Output loss saved (percent)','interpreter','latex');
title('B. Economic outcomes - Output loss saved','interpreter','latex');
set(gca,'ticklabelinterpreter','latex');
set(gca,'fontsize',16);
ytickformat('%4.0f');
xlim([0,165]);
set(gca,'xtick',[0,40,80,120,160]);
ylim([5,27]);

saveas(gcf,'.\main_text_figures\fig9_in_paper.png')

% https://www.ncbi.nlm.nih.gov/pmc/articles/PMC387602/
