% This file will produce graphs of constant deaths bi-eekly testing for
% other calibrations: 
% Ceteris paribus,
% 1. IFR: consider 1.5% and 0.5%  (original = 1%)
% 2. rel_rho : consider a value of 0.5 (original = 1)
% 3. psi: consider 0.75 and 0.5   (original = 0.6)  
% 4. gamma: consider +2/-2 days   (original = 8)
% 5. sigma: consider +2/-2 days   (original = 6)

clear all; clc; close all;

%__________________________________________________________________________
% from baseline
hrs           = 14;
rU_start      = 0.00275 ;

%__________________________________________________________________________
% robustness configuration
robust_grid   = [1:1:7];
IFR_grid      = [0.005 0.015];
rel_rho_grid  = [0.5];
psi_grid      = [0.5 0.75];
gamma_grid    = [6*hrs 10*hrs];
sigma_grid    = [4*hrs 8*hrs];
R0_grid       = [2 3];
rU_start_grid  = [0.5 1.5]*rU_start ;

% The values we give them here don't matter, they will be rectified
% in robustness_func. They needs to be defined in order jump start the
% process

IFR_robust     = 0.1;
rel_rho_robust = 1;
psi_robust     = 1;
gamma_robust   = 1;
sigma_robust   = 1;
R0_robust      = 1;
rU_start_robust = rU_start ; 

% store parameters to check
calib1 = zeros(2,7) ;
calib2 = zeros(1,7) ;
calib3 = zeros(1,7) ;
calib4 = zeros(2,7) ;
calib5 = zeros(2,7) ;
calib6 = zeros(2,7) ;
calib7 = zeros(2,7) ;

% set weeks between tests
weeks = 2;

 
%% Computation part

for robust = robust_grid  

if robust==1      
    for round = 1:length(IFR_grid)
        IFR_robust = IFR_grid(round);    
        calib1(round,:) = robustness_func (weeks,robust,round,IFR_robust,rel_rho_robust,psi_robust,sigma_robust,gamma_robust,R0_robust,rU_start_robust);  
    end   
end

if robust==2
    for round = 1:length(rel_rho_grid)
        rel_rho_robust = rel_rho_grid(round);    
        calib2(round,:) = robustness_func (weeks,robust,round,IFR_robust,rel_rho_robust,psi_robust,sigma_robust,gamma_robust,R0_robust,rU_start_robust);  
    end   
end

if robust==3
    for round = 1:length(psi_grid)
        psi_robust = psi_grid(round);    
        calib3(round,:) = robustness_func (weeks,robust,round,IFR_robust,rel_rho_robust,psi_robust,sigma_robust,gamma_robust,R0_robust,rU_start_robust);  
    end   
end

if robust==4
    for round = 1:length(gamma_grid)
        gamma_robust = gamma_grid(round);    
        calib4(round,:) = robustness_func (weeks,robust,round,IFR_robust,rel_rho_robust,psi_robust,sigma_robust,gamma_robust,R0_robust,rU_start_robust);  
    end   
end

if robust==5
    for round = 1:length(sigma_grid)
        sigma_robust = sigma_grid(round);    
        calib5(round,:) = robustness_func (weeks,robust,round,IFR_robust,rel_rho_robust,psi_robust,sigma_robust,gamma_robust,R0_robust,rU_start_robust);  
    end   
end

if robust==6
    for round = 1:length(R0_grid)
        R0_robust = R0_grid(round);    
        calib6(round,:) = robustness_func (weeks,robust,round,IFR_robust,rel_rho_robust,psi_robust,sigma_robust,gamma_robust,R0_robust,rU_start_robust);  
    end   
end


if robust==7
    for round = 1:length(rU_start_grid)
        rU_start_robust = rU_start_grid(round);    
        calib7(round,:) = robustness_func (weeks,robust,round,IFR_robust,rel_rho_robust,psi_robust,sigma_robust,gamma_robust,R0_robust,rU_start_robust);  
    end   
end


end

save robustness_calib


%% Plotting part
clear; clc; load robustness_calib;
for robust = robust_grid  

if robust==1      
    for round = 1:length(IFR_grid)
        robustness_plot_func(robust,round);  
    end   
end

if robust==2
    for round = 1:length(rel_rho_grid)
        robustness_plot_func(robust,round);  
    end   
end

if robust==3
    for round = 1:length(psi_grid)
        robustness_plot_func(robust,round);  
    end   
end

if robust==4
    for round = 1:length(gamma_grid)
        robustness_plot_func(robust,round);    
    end   
end

if robust==5
    for round = 1:length(sigma_grid)
        robustness_plot_func(robust,round);
    end   
end

if robust==6
    for round = 1:length(R0_grid)
        robustness_plot_func(robust,round);
    end   
end

if robust==7
    for round = 1:length(rU_start_grid)
        robustness_plot_func(robust,round);
    end   
end

end








